@@ -1,3 +1,3 @@
 
-from wiki_data_dump.core import WikiDump, all_mirrors
+from wiki_data_dump.core import WikiDump
 from wiki_data_dump.api_response import Wiki, Job, File
